@@ -432,6 +432,7 @@ public:
 	~TypeType() override { Unref(type); }
 
 	BroType* Type()	{ return type; }
+	const BroType* Type() const	{ return type; }
 
 protected:
 	TypeType()	{}
@@ -499,6 +500,12 @@ public:
 		return decl && decl->FindAttr(ATTR_DEPRECATED) != 0;
 		}
 
+	bool FieldHasAttr(int field, attr_tag at) const
+		{
+		const TypeDecl* decl = FieldDecl(field);
+		return decl && decl->FindAttr(at) != 0;
+		}
+
 	string GetFieldDeprecationWarning(int field, bool has_check) const;
 
 protected:
