@@ -5,6 +5,7 @@
 #include <ctype.h>
 #include <sys/types.h>
 #include <sys/socket.h>
+#include <netinet/in.h>
 #include <arpa/inet.h>
 
 #include "NetVar.h"
@@ -766,7 +767,7 @@ int DNS_Interpreter::ParseRR_TSIG(DNS_MsgInfo* msg,
 	unsigned int sign_time_msec = ExtractShort(data, len);
 	unsigned int fudge = ExtractShort(data, len);
 	BroString* request_MAC;
-	ExtractOctets(data, len, &request_MAC);
+	ExtractOctets(data, len, dns_TSIG_addl ? &request_MAC : nullptr);
 	unsigned int orig_id = ExtractShort(data, len);
 	unsigned int rr_error = ExtractShort(data, len);
 	ExtractOctets(data, len, 0);  // Other Data
@@ -1651,6 +1652,12 @@ void Contents_DNS::Flush()
 	}
 
 void Contents_DNS::DeliverStream(int len, const u_char* data, bool orig)
+	{
+	while ( len > 0 )
+		ProcessChunk(len, data, orig);
+	}
+
+void Contents_DNS::ProcessChunk(int& len, const u_char*& data, bool orig)
 	{
 	if ( state == DNS_LEN_HI )
 		{
@@ -1699,6 +1706,9 @@ void Contents_DNS::DeliverStream(int len, const u_char* data, bool orig)
 	for ( n = 0; buf_n < msg_size && n < len; ++n )
 		msg_buf[buf_n++] = data[n];
 
+	data += n;
+	len -= n;
+
 	if ( buf_n < msg_size )
 		// Haven't filled up the message buffer yet, no more to do.
 		return;
@@ -1707,10 +1717,6 @@ void Contents_DNS::DeliverStream(int len, const u_char* data, bool orig)
 
 	buf_n = 0;
 	state = DNS_LEN_HI;
-
-	if ( n < len )
-		// More data to munch on.
-		DeliverStream(len - n, data + n, orig);
 	}
 
 DNS_Analyzer::DNS_Analyzer(Connection* conn)
