@@ -701,8 +701,9 @@ string strreplace(const string& s, const string& o, const string& n)
 
 std::string strstrip(std::string s)
 	{
-	s.erase(s.begin(), std::find_if(s.begin(), s.end(), std::not1(std::ptr_fun<int, int>(std::isspace))));
-	s.erase(std::find_if(s.rbegin(), s.rend(), std::not1(std::ptr_fun<int, int>(std::isspace))).base(), s.end());
+	auto notspace = [](unsigned char c) { return ! std::isspace(c); };
+	s.erase(s.begin(), std::find_if(s.begin(), s.end(), notspace));
+	s.erase(std::find_if(s.rbegin(), s.rend(), notspace).base(), s.end());
 	return s;
 	}
 
@@ -789,7 +790,7 @@ static unsigned int first_seed = 0;
 
 static void bro_srandom(unsigned int seed, bool deterministic)
 	{
-	bro_rand_state = seed;
+	bro_rand_state = seed == 0 ? 1 : seed;
 	bro_rand_determistic = deterministic;
 
 	srandom(seed);
@@ -798,7 +799,7 @@ static void bro_srandom(unsigned int seed, bool deterministic)
 void bro_srandom(unsigned int seed)
 	{
 	if ( bro_rand_determistic )
-		bro_rand_state = seed;
+		bro_rand_state = seed == 0 ? 1 : seed;
 	else
 		srandom(seed);
 	}
@@ -905,18 +906,22 @@ bool have_random_seed()
 unsigned int bro_prng(unsigned int  state)
 	{
 	// Use our own simple linear congruence PRNG to make sure we are
-	// predictable across platforms.
-	static const long int m = 2147483647;
-	static const long int a = 16807;
-	const long int q = m / a;
-	const long int r = m % a;
+	// predictable across platforms.  (Lehmer RNG, Schrage's method)
+	constexpr uint32_t m = 2147483647;
+	constexpr uint32_t a = 16807;
+	constexpr uint32_t q = m / a;
+	constexpr uint32_t r = m % a;
 
-	state = a * ( state % q ) - r * ( state / q );
+	uint32_t rem = state % q;
+	uint32_t div = state / q;
+	int32_t s = a * rem;
+	int32_t t = r * div;
+	int32_t res = s - t;
 
-	if ( state <= 0 )
-		state += m;
+	if ( res < 0 )
+		res += m;
 
-	return state;
+	return res;
 	}
 
 long int bro_random()
@@ -1181,7 +1186,6 @@ vector<string>* tokenize_string(string input, const string& delim,
 	return rval;
 	}
 
-
 string normalize_path(const string& path)
 	{
 	size_t n;
@@ -1201,10 +1205,30 @@ string normalize_path(const string& path)
 
 		if ( *it == "." && it != components.begin() )
 			final_components.pop_back();
-		else if ( *it == ".." && final_components[0] != ".." )
+		else if ( *it == ".." )
 			{
-			final_components.pop_back();
-			final_components.pop_back();
+			auto cur_idx = final_components.size() - 1;
+
+			if ( cur_idx != 0 )
+				{
+				auto last_idx = cur_idx - 1;
+				auto& last_component = final_components[last_idx];
+
+				if ( last_component == "/" || last_component == "~" ||
+				     last_component == ".." )
+					continue;
+
+				if ( last_component == "." )
+					{
+					last_component = "..";
+					final_components.pop_back();
+					}
+				else
+					{
+					final_components.pop_back();
+					final_components.pop_back();
+					}
+				}
 			}
 		}
 
